==> apache-log4j2_2.12.4.orig.tar.xz: logging-log4j2-rel-2.12.4/log4j-core/src/test/java/org/apache/logging/log4j/core/CustomLevelsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache license, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the license for the specific language governing permissions and
 * limitations under the license.
 */
package org.apache.logging.log4j.core;

import static org.hamcrest.Matchers.hasSize;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertThat;

import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.junit.LoggerContextRule;
import org.apache.logging.log4j.test.appender.ListAppender;
import org.junit.Before;
import org.junit.ClassRule;
import org.junit.Test;

public class CustomLevelsTest {

    private static final String CONFIG = "log4j-customLevels.xml";

    @ClassRule
    public static LoggerContextRule context = new LoggerContextRule(CONFIG);

    private ListAppender listAppender;
    private Level diagLevel;
    private Level noticeLevel;
    private Level verboseLevel;

    @Before
    public void before() {
        diagLevel = Level.getLevel("DIAG");
        noticeLevel = Level.getLevel("NOTICE");
        verboseLevel = Level.getLevel("VERBOSE");
        listAppender = context.getListAppender("List1").clear();
    }

    @Test
    public void testCustomLevelInts() {
        assertEquals(350, diagLevel.intLevel());
        assertEquals(450, noticeLevel.intLevel());
        assertEquals(550, verboseLevel.intLevel());
    }

    @Test
    public void testCustomLevelPresence() {
        assertNotNull(diagLevel);
        assertNotNull(noticeLevel);
        assertNotNull(verboseLevel);
    }

    @Test
    public void testLog() {
        final Logger logger = context.getLogger();
        assertThat(listAppender.getEvents(), hasSize(0));
        logger.debug("Hello, {}", "World");
        assertThat(listAppender.getEvents(), hasSize(1));
        logger.log(diagLevel, "Hello DIAG");
        assertThat(listAppender.getEvents(), hasSize(2));
        assertEquals(listAppender.getEvents().get(1).getLevel(), diagLevel);

    }
}

==> apache-log4j2_2.19.0.orig.tar.xz: logging-log4j2-rel-2.19.0/log4j-core/src/test/java/org/apache/logging/log4j/core/CustomLevelsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache license, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the license for the specific language governing permissions and
 * limitations under the license.
 */
package org.apache.logging.log4j.core;

import static org.hamcrest.MatcherAssert.*;
import static org.hamcrest.Matchers.hasSize;
import static org.junit.jupiter.api.Assertions.*;

import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.junit.Named;
import org.apache.logging.log4j.junit.LoggerContextSource;
import org.apache.logging.log4j.test.appender.ListAppender;
import org.junit.jupiter.api.Test;

@LoggerContextSource("log4j-customLevels.xml")
public class CustomLevelsTest {

    private final ListAppender listAppender;
    private final Level diagLevel;
    private final Level noticeLevel;
    private final Level verboseLevel;
    private final Logger logger;

    public CustomLevelsTest(final LoggerContext context, @Named("List1") final ListAppender appender) {
        diagLevel = Level.getLevel("DIAG");
        noticeLevel = Level.getLevel("NOTICE");
        verboseLevel = Level.getLevel("VERBOSE");
        listAppender = appender.clear();
        logger = context.getLogger(getClass().getName());
    }

    @Test
    public void testCustomLevelInts() {
        assertEquals(350, diagLevel.intLevel());
        assertEquals(450, noticeLevel.intLevel());
        assertEquals(550, verboseLevel.intLevel());
    }

    @Test
    public void testCustomLevelPresence() {
        assertNotNull(diagLevel);
        assertNotNull(noticeLevel);
        assertNotNull(verboseLevel);
    }

    @Test
    public void testLog() {
        assertThat(listAppender.getEvents(), hasSize(0));
        logger.debug("Hello, {}", "World");
        assertThat(listAppender.getEvents(), hasSize(1));
        logger.log(diagLevel, "Hello DIAG");
        assertThat(listAppender.getEvents(), hasSize(2));
        assertEquals(listAppender.getEvents().get(1).getLevel(), diagLevel);

    }
}
